#!/usr/bin/env node
"use strict";

var _fs = _interopRequireDefault(require("fs"));

var _yargs = _interopRequireDefault(require("yargs"));

var _baba = _interopRequireDefault(require("../baba"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_yargs.default.command(['parse <file> [key]', '$0'], 'Parse grammar and output exposed rules', yargs => {
  yargs.positional('file', {
    describe: 'JSON grammar specification or npm package containing specification',
    type: 'string',
    coerce: arg => {
      let contents;

      try {
        contents = require(arg);
      } catch (e) {
        contents = JSON.parse(_fs.default.readFileSync(arg, 'utf8'));
      }

      return contents;
    }
  }).positional('key', {
    describe: 'Exposed key',
    type: 'string'
  });
}, argv => {
  const baba = (0, _baba.default)(argv.file);

  if (!argv.key || !baba.expose[argv.key]) {
    console.log('\nExposed references:');

    for (const [key, value] of Object.entries(baba.expose)) {
      console.log(` - ${key}: ${value}`);
    }

    console.log('\nVariables:');

    for (const [key, value] of Object.entries(baba.variable)) {
      console.log(` - ${key}: ${value}`);
    }

    for (const [key, value] of Object.entries(baba.expose)) {
      console.log(`\n${value}\n${'-'.repeat(value.length)}\n${baba.ruleFromPath(key)()}`);
    }

    return;
  }

  console.log(baba.ruleFromPath(argv.key)());
}).argv;