"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isObject = isObject;
exports.mergeDeep = mergeDeep;
exports.selectRandom = selectRandom;
exports.nodeFromPath = nodeFromPath;

function isObject(item) {
  return item && typeof item === 'object' && !Array.isArray(item);
}

function mergeDeep(target, source) {
  let output = Object.assign({}, target);

  if (isObject(target) && isObject(source)) {
    Object.keys(source).forEach(key => {
      if (isObject(source[key])) {
        if (!(key in target)) {
          Object.assign(output, {
            [key]: source[key]
          });
        } else {
          output[key] = mergeDeep(target[key], source[key]);
        }
      } else {
        Object.assign(output, {
          [key]: source[key]
        });
      }
    });
  }

  return output;
}

function selectRandom(array) {
  return array[Math.floor(Math.random() * array.length)];
}

function nodeFromPath(obj, path, silent) {
  const arr = path.split('.');
  let objRef = obj;

  while (arr.length && (objRef = objRef[arr.shift()])) {} // eslint-disable-line


  if (typeof objRef === 'undefined' && !silent) {
    throw new Error(`Undefined property path: "${path}"`);
  }

  return objRef;
}